.. _api_client:

********************
Zenodo Client Module
********************
.. currentmodule:: zenopy.client

Class Signature
===============

.. autosummary:: Zenodo

Member Functions
================

.. autosummary::
    :nosignatures:

    Zenodo.create_config_file
    Zenodo.init_deposition_actions
    Zenodo.init_deposition_file
    Zenodo.init_records
    Zenodo.init_resources
    Zenodo.list_sections
    Zenodo.list_tokens
    Zenodo.read_config_file
    Zenodo.read_token
    Zenodo.update_config_file
    Zenodo.write_token

Specifications
==============

.. autoclass:: Zenodo
    :members: